/*
	length-converter.js
	
	we'll use m for our base unit
	m = meters
	
	m 1
	mm 1000
	cm 100
	km 0.001
	ft 3.28084
	in 39.37008
	mi 0.0006213712
	yd 1.093613
*/

class LengthConverter {
	
	constructor(unit, value) {
		//unit is "c" or "f" for Celsius and Fahrenheit
		this.results = [];		
		this.unitName = unit.toLowerCase();
		this.value = parseFloat(value);
		this.convert();
	}
	
	getResults() {
		return this.results;
	}
	
	//----------------------	
	//private calcs
	
	convert() {
		const
			factorsMap = this.conversionFactors(),
			factor = factorsMap.get(this.unitName),
			baseValue = this.value / factor;
		for (const unitFactorPair of factorsMap){
			let convertedValue = baseValue * unitFactorPair[1];
			//round to five dec places
			convertedValue = Math.round(convertedValue * 100000) / 100000;
			this.addResult(unitFactorPair[0], convertedValue);
		}
	}
	
	//----------------------	
	//Helpers
	
	addResult(unit, value) {
		//add as nice simple js plain object
		this.results.push({unit: unit, value: value});
	}	
	
	conversionFactors() {
		return new Map(
			[['m', 1],
			['ft', 3.28084],			
			['mm', 1000],
			['cm', 100],						
			['km', 0.001],
			['in', 39.37008],
			['mi', 0.0006213712],	
			['yd', 1.093613]]);				
	}
	
}

//=====================================	

exports.LengthConverter = LengthConverter;	
	
