/*
temperature-converter.js
	
Temperature converter
	
I have a given unit and a value. I convert these
values to other temperature units.

To keep it simple, we only compute Celsius and Fahrenheit

Thx
*/

class TemperatureConverter {
	
	constructor(unit, value) {
		//unit is "c" or "f" for Celsius and Fahrenheit
		this.results = [];		
		this.unit = unit.toLowerCase();
		this.value = parseFloat(value);
		this.convert();
	}
	
	getResults() {
		return this.results;
	}	
	
	//----------------------	
	//private calcs
	
	convert() {
		const unit = this.unit;
		if (unit === 'c')
			this.convertCelsius();
		else if (unit === 'f')
			this.convertFahrenheit();
		else
			throw `Unit not supported ${unit}`;
	}
		
	convertCelsius() {
		const unitC = this.unit;		
		const tempC = this.value;
		//add (given value) Celsius first to output		
		this.addResult(unitC, tempC);
		this.addResult('f', this.celsiusToFahrenheit(tempC));
	}

	convertFahrenheit() {
		const unitF = this.unit;		
		const tempF = this.value;
		//add (given value) Fahrenheit first to output
		this.addResult(unitF, tempF);
		this.addResult('c', this.fahrenheitToCelsius(tempF));
	}
	
	celsiusToFahrenheit(tempC) {
		//tempC is temp in Celsius
		return (tempC * 1.8) + 32;
	}
	
	fahrenheitToCelsius(tempF) {
		//tempF is temp in Fahrenheit
		return (tempF - 32) / 1.8;
	}	
	
		
	//----------------------	
	//Helpers
	
	addResult(unit, value) {
		//add as nice simple js plain object
		//set unit as uppercase (desirable for temperature units)
		this.results.push({unit: unit.toUpperCase(), value: value});
	}

	
}

//=====================================	

exports.TemperatureConverter = TemperatureConverter;	
